@@ -1,5 +1,3 @@
-from __future__ import print_function
-
 import os
 import sys
 import re
@@ -47,6 +45,8 @@ class Command(NoArgsCommand):
         data = RequestContext(request)
         for template_dir in settings.TEMPLATE_DIRS:
             path = os.path.join(template_dir, 'js-tests')
+            if not os.path.exists(path):
+                continue
             files = [f.replace('.html', '') for f in os.listdir(path)
                      if os.path.isfile(os.path.join(path, f))]
             for ignore_file in IGNORE_QUNIT_HTML_FILES:
@@ -76,4 +76,4 @@ class Command(NoArgsCommand):
                     code, result = commands.getstatusoutput(cmd)
                 with open('reports/junit-%s.xml' % filename, 'w') as f:
                     f.write(result)
-                print(filename.title() + ' - ' + RE_RESULTS.findall(result)[0].replace('\n', ' ').strip())
+                sys.stdout.write(filename.title() + ' - ' + RE_RESULTS.findall(result)[0].replace('\n', ' ').strip())
